(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     60092,       1460]
NotebookOptionsPosition[     58033,       1399]
NotebookOutlinePosition[     58544,       1418]
CellTagsIndexPosition[     58501,       1415]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Adaptive Radiosonde Calibration Example. The files needed are\n",
 StyleBox["RadioData.dat - radiosonde mixing ratio data\nRH.dat - radiosonde \
RH data\nTempK.dat - radiosonde Temperatures in K\nRadioHeights.dat - \
radiosonde heights\nCompositeData.dat - uncalibrated lidar mixing ratio \n\
SumErrorProfTest.dat - lidar random errors\nLidarHeights.dat - lidar \
heights.", "Section"]
}], "Title",
 CellChangeTimes->{{3.550925270667094*^9, 3.550925279449894*^9}, 
   3.550925563791094*^9, {3.550933422670818*^9, 3.5509335229457135`*^9}, {
   3.5509357106730814`*^9, 3.550935788419181*^9}, {3.5509358476112814`*^9, 
   3.550935868285981*^9}, {3.5509414851787605`*^9, 3.5509414888135605`*^9}}],

Cell[TextData[StyleBox["Submitted as supplemental data for \"Correction \
technique for raman water vapor lidar aignal dependent bias and suitability \
for water vapor trend monitoring in the upper troposphere\".",
 FontSlant->"Italic"]], "Subsubtitle",
 CellChangeTimes->{{3.550937148762496*^9, 3.550937232449564*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
Mathematica routines needed for the example to function. \
GetRadioCalFactorRegress is the last routine defined in this section.\
\>", "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.5509360030904813`*^9, 3.550936046853781*^9}, {
  3.550936982927848*^9, 3.5509369994013424`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetLastPositionLess", "[", 
   RowBox[{"InputList_", ",", "Value_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "i", "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ";", "\n", "\t\t", 
     RowBox[{"While", "[", "\n", "\t\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"InputList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], " ", "<", " ", "Value"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "\[Equal]", " ", 
           RowBox[{"Length", "[", "InputList", "]"}]}], ",", 
          RowBox[{
           RowBox[{"i", "++"}], ";", 
           RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
        RowBox[{"i", "++"}]}]}], "]"}], ";", "\n", "\t\t\t", 
     RowBox[{"i", "-", "1"}]}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 ShowGroupOpener->True,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.550936982927848*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GetFirstPositionGreater", "[", 
   RowBox[{"InputList_", ",", "Value_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "i", "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ";", "\n", "\t\t", 
     RowBox[{"While", "[", "\n", "\t\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"InputList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], " ", "\[LessEqual]", " ", "Value"}], 
       ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "\[Equal]", " ", 
           RowBox[{"Length", "[", "InputList", "]"}]}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", 
        RowBox[{"i", "++"}], ";"}]}], "]"}], ";", "\n", "\t\t\t", "i"}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 ShowGroupOpener->True,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.550936982927848*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RunningSum", "[", 
   RowBox[{"InputList_", ",", "PointsToSum_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Nmax", ",", "i", ",", "j", ",", 
      RowBox[{"OutList", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"Nmax", "=", 
      RowBox[{"IntegerPart", "[", 
       RowBox[{
        RowBox[{"Length", "[", "InputList", "]"}], "/", "PointsToSum"}], 
       "]"}]}], ";", "\n", "\t\t", 
     RowBox[{"i", "=", "1"}], ";", 
     RowBox[{"j", "=", "PointsToSum"}], ";", "\n", "\t\t", 
     RowBox[{"Do", "[", "\n", "\t\t\t", 
      RowBox[{
       RowBox[{
        RowBox[{"OutList", "=", 
         RowBox[{"{", 
          RowBox[{"OutList", ",", 
           RowBox[{"Plus", "@@", 
            RowBox[{"Take", "[", 
             RowBox[{"InputList", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], "}"}]}], ";", 
        "\n", "\t\t\t", 
        RowBox[{"i", "+=", "PointsToSum"}], ";", 
        RowBox[{"j", "+=", "PointsToSum"}], ";"}], ",", "\n", "\t\t\t", 
       RowBox[{"{", "Nmax", "}"}]}], "]"}], ";", "\n", "\t\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", 
         RowBox[{"InputList", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], ">", "1"}], ",", 
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", "OutList", "]"}], ",", 
         RowBox[{"Length", "[", 
          RowBox[{"InputList", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ",", 
       RowBox[{"Flatten", "[", "OutList", "]"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.449435533630065*^9, 3.550936982927848*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MyMedian", "[", "list1_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s", ",", "n"}], "}"}], ",", 
     RowBox[{
      RowBox[{"s", "=", 
       RowBox[{"Sort", "[", "list1", "]"}]}], ";", 
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "list1", "]"}]}], ";", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", "\[LeftDoubleBracket]", 
          FractionBox["n", "2"], "\[RightDoubleBracket]"}], "+", 
         RowBox[{"s", "\[LeftDoubleBracket]", 
          RowBox[{
           FractionBox["n", "2"], "+", "1"}], "\[RightDoubleBracket]"}]}], 
        ")"}]}]}]}], "]"}], "/;", 
   RowBox[{"EvenQ", "[", 
    RowBox[{"Length", "[", "list1", "]"}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.550936982927848*^9}],

Cell["Least Median of Squares. From Shaw - Tigg.", "Subsubtitle",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.550936343521081*^9, 3.550936358145381*^9}, 
   3.550936982927848*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lmsfita", "[", 
   RowBox[{"data_", ",", "x_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "l", ",", "v", ",", "i", ",", "j", ",", "w", ",", "h", ",", "a", ",", 
      "sl", ",", "dx"}], "}"}], ",", 
    RowBox[{
     RowBox[{"l", "=", 
      RowBox[{"Length", "[", "data", "]"}]}], ";", 
     RowBox[{"v", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
            "data", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            ",", 
            RowBox[{
            "data", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"l", "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", 
            RowBox[{"i", "+", "1"}], ",", "l"}], "}"}]}], "]"}], ",", "1"}], 
       "]"}]}], ";", 
     RowBox[{"w", "=", 
      RowBox[{"Union", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Module", "[", 
           RowBox[{
            RowBox[{"{", "dx", "}"}], ",", 
            RowBox[{
             RowBox[{"dx", "=", 
              RowBox[{
               RowBox[{"#1", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
               RowBox[{"#1", "\[LeftDoubleBracket]", 
                RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"dx", "\[NotEqual]", "0"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 FractionBox[
                  RowBox[{
                   RowBox[{"#1", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
                   RowBox[{"#1", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                  "dx"], ",", 
                 FractionBox[
                  RowBox[{
                   RowBox[{
                    RowBox[{"#1", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"#1", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], "-", 
                   RowBox[{
                    RowBox[{"#1", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"#1", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
                  "dx"]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", 
                 RowBox[{"#1", "\[LeftDoubleBracket]", 
                  RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                "}"}]}], "]"}]}]}], "]"}], "&"}], ")"}], "/@", "v"}], "]"}]}],
      ";", 
     RowBox[{"h", "=", 
      RowBox[{"Function", "[", 
       RowBox[{"a", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"MyMedian", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "a", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 "\[NotEqual]", "\[Infinity]"}], ",", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                   "#1", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "-", 
                   RowBox[{
                    RowBox[{
                    "a", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{
                    "#1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "-", 
                   RowBox[{
                   "a", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], ")"}], "2"], ",", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                   "a", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "-", 
                   RowBox[{
                   "#1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], ")"}], "2"]}], "]"}], "&"}], 
             ")"}], "/@", "data"}], "]"}], ",", 
          RowBox[{"a", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           ",", 
          RowBox[{
          "a", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         "}"}]}], "]"}]}], ";", 
     RowBox[{"sl", "=", 
      RowBox[{
       RowBox[{"Sort", "[", 
        RowBox[{"h", "/@", "w"}], "]"}], "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"sl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[NotEqual]", "\[Infinity]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"sl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
          " ", "x"}], "+", 
        RowBox[{
        "sl", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<x = \>\"", ",", 
         RowBox[{
         "sl", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
        "]"}]}], "]"}]}]}], "]"}]}]], "Input",
 ShowGroupOpener->True,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.4641709064986796`*^9, 3.4641709068296795`*^9}, 
   3.4908526693249397`*^9},
 AspectRatioFixed->True],

Cell["\<\
Adaptive Radiosonde Caibration Routine. The algorithmn works as follows:

1) interpolate data to height grid approximating the sonde vertical resolution
2) Select initial population of points based on RSquare of linear least \
squares regressions of subsets of data
3) Delete duplicate points
4) presum interpolated data to approximate lidar vertical resolution
5) Perform Least Median of Squares regression
6) Remove outliers based on percentage devation from PredictedResponse
7) If sufficient number of points, Use these points to calculate the final \
calibration value by taking the Mean ratio of the points. Also perform linear \
regression on final points.
8) If not sufficient points, decrease Rsquare and AcceptancePercentage values \
and repeat\
\>", "Subsubtitle",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.491129367686572*^9, 3.491129405295333*^9}, {
   3.491143817777229*^9, 3.491144124689229*^9}, 3.550936982927848*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GetRadioCalFactorRegress", "[", 
    RowBox[{
    "RadioMRData_", ",", "RadioRHData_", ",", "RadioTData_", ",", 
     "RadioHeights_", ",", "LidarData_", ",", "LidarDataErrs_", ",", 
     "LidarHeights_", ",", "MinCalAlt_", ",", "MaxCalAlt_", ",", 
     "MinRSquareIni_", ",", "RegressionIntervalKM_", ",", 
     "AcceptancePercentageIni_", ",", "MinNumberRegressionPoints_", ",", 
     "MinRH_", ",", "MinTempC_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "MinRadioBin", ",", "MaxRadioBin", ",", "MinLidarBin", ",", 
       "MaxLidarBin", ",", "SubsetRadioHeights", ",", "SubsetRadioMRData", 
       ",", "SubsetRadioRHData", ",", "SubsetRadioTData", ",", 
       "SubsetLidarHeights", ",", "SubsetLidarData", ",", "MeanDeltaH", ",", 
       " ", "HeightsForInterp", ",", "HeightsForInterpNew", ",", 
       "HeightsForInterpNew2", ",", "DataR", ",", "DataL", ",", "RadioMRFunc",
        ",", "RadioRHFunc", ",", "RadioTFunc", ",", "LidarFunc", ",", " ", 
       "InterpRadioMRData", ",", "InterpRadioRHData", ",", "InterpRadioTData",
        ",", "InterpLidarData", ",", "LidarResolution", ",", 
       "MeanSondeResolution", ",", "PresumNumber", ",", "SondeMRDataNew", ",",
        "SondeRHDataNew", ",", "SondeTDataNew", ",", "SondeDataNew2", ",", 
       "LidarDataNew", ",", "LidarDataNew2", ",", "SelectedData", ",", 
       "RegressionData", ",", "ThisRegressionData", ",", "FinalResolution", 
       ",", " ", "NumToRegress", ",", "NumberOfRegressions", ",", 
       "ThisRegression", ",", "ThisRSquare", ",", "PointsToSave", ",", 
       "SinglePointsToSave", ",", "PointsToRegress", ",", "linfit", ",", 
       "lmslinfit", ",", "PredictedLMSResponse", ",", "LMSResiduals", ",", 
       "LMSRatios", ",", " ", "GoodPoints1", ",", "FinalRegressionPoints", 
       ",", "InitialLinFit", ",", " ", "FinalLinFit", ",", " ", 
       "InitialDataPoints", ",", " ", "FinalDataPoints", ",", "InitialCalVal",
        ",", " ", "FinalCalVal", ",", "ThisMinRSquare", ",", " ", 
       "ThisAcceptancePercentage", ",", "GoodPoints", ",", "lm", ",", "x", 
       ",", "i"}], "}"}], ",", "\n", "\t\t", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"MinRadioBin", "=", 
       RowBox[{"GetFirstPositionGreater", "[", 
        RowBox[{"RadioHeights", ",", "MinCalAlt"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"MaxRadioBin", "=", 
       RowBox[{"GetLastPositionLess", "[", 
        RowBox[{"RadioHeights", ",", "MaxCalAlt"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"MinLidarBin", "=", 
       RowBox[{"GetFirstPositionGreater", "[", 
        RowBox[{"LidarHeights", ",", "MinCalAlt"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"MaxLidarBin", "=", 
       RowBox[{"GetLastPositionLess", "[", 
        RowBox[{"LidarHeights", ",", "MaxCalAlt"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\t\t", "\n", 
      RowBox[{"SubsetRadioHeights", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"RadioHeights", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MinRadioBin", "-", "1"}], ",", 
           RowBox[{"MaxRadioBin", "+", "1"}]}], "}"}]}], "]"}]}], ";", "\t", 
      "\[IndentingNewLine]", 
      RowBox[{"SubsetRadioMRData", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"RadioMRData", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MinRadioBin", "-", "1"}], ",", 
           RowBox[{"MaxRadioBin", "+", "1"}]}], "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"SubsetRadioRHData", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"RadioRHData", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MinRadioBin", "-", "1"}], ",", 
           RowBox[{"MaxRadioBin", "+", "1"}]}], "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"SubsetRadioTData", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"RadioTData", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MinRadioBin", "-", "1"}], ",", 
           RowBox[{"MaxRadioBin", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"SubsetLidarHeights", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"LidarHeights", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MinLidarBin", "-", "1"}], ",", 
           RowBox[{"MaxLidarBin", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"SubsetLidarData", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"LidarData", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MinLidarBin", "-", "1"}], ",", 
           RowBox[{"MaxLidarBin", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"RadioMRFunc", "=", 
       RowBox[{"Interpolation", "[", 
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{"{", 
           RowBox[{"SubsetRadioHeights", ",", "SubsetRadioMRData"}], "}"}], 
          "]"}], ",", 
         RowBox[{"InterpolationOrder", "->", "1"}]}], "]"}]}], ";", "\n", 
      RowBox[{"RadioRHFunc", "=", 
       RowBox[{"Interpolation", "[", 
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{"{", 
           RowBox[{"SubsetRadioHeights", ",", "SubsetRadioRHData"}], "}"}], 
          "]"}], ",", 
         RowBox[{"InterpolationOrder", "->", "1"}]}], "]"}]}], ";", "\n", 
      RowBox[{"RadioTFunc", "=", 
       RowBox[{"Interpolation", "[", 
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{"{", 
           RowBox[{"SubsetRadioHeights", ",", "SubsetRadioTData"}], "}"}], 
          "]"}], ",", 
         RowBox[{"InterpolationOrder", "->", "1"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"DataL", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"SubsetLidarHeights", ",", "SubsetLidarData"}], "}"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"LidarFunc", "=", 
       RowBox[{"Interpolation", "[", 
        RowBox[{"DataL", ",", 
         RowBox[{"InterpolationOrder", "->", "1"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
       "determine", " ", "which", " ", "dataset", " ", "has", " ", "higher", 
        " ", "vertical", " ", 
        RowBox[{"resolution", ".", " ", "Develop"}], " ", "height", " ", 
        "grid", " ", "using", " ", "mean", " ", "resolution", " ", "of", " ", 
        "that", " ", "dataset", " ", "and", " ", "put", " ", "all", " ", 
        "data", " ", "on", " ", "the", " ", "same", " ", "height", " ", 
        "grid"}], " ", "*)"}], "\[IndentingNewLine]", "\n", 
      RowBox[{"LidarResolution", "=", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"LidarHeights", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "-", 
         RowBox[{"LidarHeights", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"MeanSondeResolution", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"SubsetRadioHeights", "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], "-", 
          RowBox[{"SubsetRadioHeights", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
        RowBox[{"Length", "[", "SubsetRadioHeights", "]"}]}]}], ";", "\n", 
      RowBox[{"MeanDeltaH", "=", 
       RowBox[{"Min", "[", 
        RowBox[{"LidarResolution", ",", "MeanSondeResolution"}], "]"}]}], ";",
       "\n", 
      RowBox[{"HeightsForInterp", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"SubsetRadioHeights", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "-", "1"}], ")"}], " ", "MeanDeltaH"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{
            RowBox[{"IntegerPart", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"MaxCalAlt", "-", "MinCalAlt"}], ")"}], "/", 
              "MeanDeltaH"}], "]"}], "-", "1"}]}], "}"}]}], "]"}]}], ";", 
      "\n", "\n", "\[IndentingNewLine]", 
      RowBox[{"InterpRadioMRData", "=", 
       RowBox[{"RadioMRFunc", "[", "HeightsForInterp", "]"}]}], ";", "\n", 
      RowBox[{"InterpRadioRHData", "=", 
       RowBox[{"RadioRHFunc", "[", "HeightsForInterp", "]"}]}], ";", "\n", 
      RowBox[{"InterpRadioTData", "=", 
       RowBox[{"RadioTFunc", "[", "HeightsForInterp", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"InterpLidarData", "=", 
       RowBox[{"LidarFunc", "[", "HeightsForInterp", "]"}]}], ";", "\n", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "presum", " ", "data", " ", "to", " ", "approximate", " ", "the", " ", 
        "resolution", " ", "of", " ", "the", " ", "lidar", " ", "data"}], " ",
        "*)"}], "\n", "\n", 
      RowBox[{"PresumNumber", "=", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"IntegerPart", "[", 
          RowBox[{"LidarResolution", "/", "MeanDeltaH"}], " ", "]"}], ",", 
         "1"}], "]"}]}], ";", "\n", 
      RowBox[{"HeightsForInterpNew", "=", 
       RowBox[{
        RowBox[{"RunningSum", "[", 
         RowBox[{"HeightsForInterp", ",", "PresumNumber"}], "]"}], "/", 
        "PresumNumber"}]}], ";", "\n", 
      RowBox[{"SondeMRDataNew", "=", 
       RowBox[{
        RowBox[{"RunningSum", "[", 
         RowBox[{"InterpRadioMRData", ",", "PresumNumber"}], "]"}], "/", 
        "PresumNumber"}]}], ";", "\n", 
      RowBox[{"SondeRHDataNew", "=", 
       RowBox[{
        RowBox[{"RunningSum", "[", 
         RowBox[{"InterpRadioRHData", ",", "PresumNumber"}], "]"}], "/", 
        "PresumNumber"}]}], ";", "\n", 
      RowBox[{"SondeTDataNew", "=", 
       RowBox[{
        RowBox[{"RunningSum", "[", 
         RowBox[{"InterpRadioTData", ",", "PresumNumber"}], "]"}], "/", 
        "PresumNumber"}]}], ";", "\n", 
      RowBox[{"LidarDataNew", "=", 
       RowBox[{
        RowBox[{"RunningSum", "[", 
         RowBox[{"InterpLidarData", ",", "PresumNumber"}], "]"}], "/", 
        "PresumNumber"}]}], ";", "\n", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
       "select", " ", "the", " ", "data", " ", "according", " ", "to", " ", 
        "RH", " ", "and", " ", "T", " ", "thresholds", " ", "if", " ", 
        "desired"}], " ", "*)"}], "\n", "\n", 
      RowBox[{"SelectedData", "=", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{"{", 
           RowBox[{
           "SondeMRDataNew", ",", "SondeRHDataNew", ",", "SondeTDataNew", ",",
             "LidarDataNew", ",", "HeightsForInterpNew"}], "}"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ">", "MinRH"}], "&&", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], ">", "MinTempC"}]}], "&"}]}], 
        "]"}]}], ";", "\n", 
      RowBox[{"LidarDataNew2", "=", 
       RowBox[{
        RowBox[{"Transpose", "[", "SelectedData", "]"}], "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ";", "\n", 
      RowBox[{"SondeDataNew2", "=", 
       RowBox[{
        RowBox[{"Transpose", "[", "SelectedData", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", 
      RowBox[{"HeightsForInterpNew2", "=", 
       RowBox[{
        RowBox[{"Transpose", "[", "SelectedData", "]"}], "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], ";", "\n", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
       "initial", " ", "linear", " ", "fit", " ", "and", " ", "mean", " ", 
        "cal", " ", "constant"}], " ", "*)"}], "\n", "\n", 
      RowBox[{"InitialLinFit", "=", 
       RowBox[{
        RowBox[{"LinearModelFit", "[", 
         RowBox[{
          RowBox[{"Thread", "[", 
           RowBox[{"{", 
            RowBox[{"LidarDataNew2", ",", "SondeDataNew2"}], "}"}], "]"}], 
          ",", "x", ",", "x"}], "]"}], "[", "\"\<BestFitParameters\>\"", 
        "]"}]}], ";", "\n", 
      RowBox[{"InitialCalVal", "=", 
       RowBox[{"Mean", "[", 
        RowBox[{"SondeDataNew2", "/", "LidarDataNew2"}], "]"}]}], ";", "\n", 
      RowBox[{"InitialDataPoints", "=", 
       RowBox[{"{", 
        RowBox[{
        "LidarDataNew2", ",", "SondeDataNew2", ",", "HeightsForInterpNew2"}], 
        "}"}]}], ";", "\n", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Determine", " ", "how", " ", "many", " ", "points", " ", "in", " ", 
        "each", " ", "regression", " ", "and", " ", "how", " ", "many", " ", 
        "total", " ", "regressions"}], " ", "*)"}], "\n", "\n", 
      RowBox[{"FinalResolution", "=", 
       RowBox[{
        RowBox[{"HeightsForInterpNew", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", 
        RowBox[{"HeightsForInterpNew", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\n", 
      RowBox[{"NumToRegress", "=", 
       RowBox[{"IntegerPart", "[", 
        RowBox[{"RegressionIntervalKM", "/", "FinalResolution"}], "]"}]}], 
      ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "number", " ", "of", " ", "points", " ", "to", " ", "use", " ", "in", 
        " ", "each", " ", "regression"}], " ", "*)"}], "\n", 
      RowBox[{"NumberOfRegressions", "=", 
       RowBox[{
        RowBox[{"Length", "[", "LidarDataNew2", "]"}], "-", "NumToRegress", 
        "+", "1"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "total", " ", "number", " ", "of", " ", "regressions", " ", "in", " ", 
        "the", " ", "While", " ", "loop"}], " ", "*)"}], "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "NumToRegress", ",", "\"\< \>\"", ",", "NumberOfRegressions"}], 
         "]"}], ";"}], "*)"}], "\n", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "select", " ", "points", " ", "within", " ", "user", " ", "defined", 
         " ", "region", " ", "based", " ", "on", " ", "R"}], "-", 
        RowBox[{
         RowBox[{"square", ".", " ", "Retain"}], " ", "a", " ", "point", " ", 
         "if", " ", "it", " ", "is", " ", "in", " ", "any", " ", "regression",
          " ", "interval", " ", "that", " ", 
         RowBox[{"qualifies", ".", " ", "Maintain"}], " ", "height", " ", 
         "at", " ", "which", " ", "points", " ", 
         RowBox[{"occur", ".", " ", "Eliminate"}], " ", "duplicate", " ", 
         RowBox[{"points", "."}]}]}], " ", "*)"}], "\n", "\n", 
      RowBox[{"RegressionData", "=", 
       RowBox[{"Thread", "[", 
        RowBox[{"{", 
         RowBox[{
         "LidarDataNew2", ",", "SondeDataNew2", ",", "HeightsForInterpNew2"}],
          "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"PointsToSave", "=", 
       RowBox[{"{", "}"}]}], ";", "\n", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
       "the", " ", "outer", " ", "while", " ", "loop", " ", "is", " ", "to", 
        " ", "adjust", " ", "the", " ", "values", " ", "of", " ", 
        "MinRSquare", " ", "and", " ", "AcceptancePercentage", " ", "if", " ",
         "insufficient", " ", "number", " ", "of", " ", "good", " ", "points",
         " ", "are", " ", "found"}], " ", "*)"}], "\n", "\n", 
      RowBox[{"ThisMinRSquare", "=", "MinRSquareIni"}], ";", "\n", 
      RowBox[{"ThisAcceptancePercentage", "=", "AcceptancePercentageIni"}], 
      ";", "\n", 
      RowBox[{"GoodPoints", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "GoodPoints", "]"}], "\[LessEqual]", " ", 
         "MinNumberRegressionPoints"}], ",", "\n", "\n", 
        RowBox[{"(*", " ", 
         RowBox[{
         "the", " ", "inner", " ", "while", " ", "loop", " ", "selects", " ", 
          "by", " ", "Rsquare", " ", "and", " ", "filters", " ", "data", " ", 
          "using", " ", "LMS", " ", "regression"}], " ", "*)"}], "\n", "\n", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"i", "\[LessEqual]", " ", "NumberOfRegressions"}], ",", 
           "\n", 
           RowBox[{
            RowBox[{"ThisRegressionData", "=", 
             RowBox[{"Take", "[", 
              RowBox[{"RegressionData", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{"i", "+", "NumToRegress", "-", "1"}]}], "}"}]}], 
              "]"}]}], ";", "\n", 
            RowBox[{"PointsToRegress", "=", 
             RowBox[{"Transpose", "[", 
              RowBox[{"Drop", "[", 
               RowBox[{
                RowBox[{"Transpose", "[", "ThisRegressionData", "]"}], ",", 
                RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", 
            RowBox[{"(*", " ", 
             RowBox[{"the", " ", 
              RowBox[{"Transpose", "[", 
               RowBox[{"Drop", "[", 
                RowBox[{
                "Transpose", " ", "operation", " ", "selects", " ", "just", 
                 " ", "the", " ", "ordered", " ", "pairs"}], " "}]}]}], 
             "*)"}], "\[IndentingNewLine]", 
            RowBox[{"lm", "=", 
             RowBox[{"LinearModelFit", "[", 
              RowBox[{"PointsToRegress", ",", "x", ",", "x"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"ThisRSquare", "=", 
             RowBox[{"lm", "[", "\"\<RSquared\>\"", "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
              "ThisRSquare", "\[GreaterEqual]", " ", "ThisMinRSquare"}], ",", 
              RowBox[{"PointsToSave", "=", 
               RowBox[{"Append", "[", 
                RowBox[{"PointsToSave", ",", "ThisRegressionData"}], 
                "]"}]}]}], "]"}], ";", 
            RowBox[{"(*", " ", 
             RowBox[{
             "the", " ", "heights", " ", "data", " ", "are", " ", "included", 
              " ", "here"}], " ", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"i", "++"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
         "\n", 
         RowBox[{"SinglePointsToSave", "=", 
          RowBox[{"DeleteDuplicates", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"PointsToSave", ",", "1"}], "]"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{
          "the", " ", "heights", " ", "data", " ", "are", " ", "included", 
           " ", "here"}], " ", "*)"}], "\n", "\n", 
         RowBox[{"(*", " ", 
          RowBox[{
          "Use", " ", "Least", " ", "median", " ", "of", " ", "squares", " ", 
           "on", " ", "this", " ", "population", " ", "of", " ", 
           RowBox[{"points", ".", " ", "Use"}], " ", "AcceptancePercentage", 
           " ", "to", " ", "eliminate", " ", "outliers", " ", "from", " ", 
           "the", " ", "LMS", " ", "fit", " ", "fit"}], " ", "*)"}], "\n", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "SinglePointsToSave", "]"}], 
            "\[GreaterEqual]", " ", "MinNumberRegressionPoints"}], ",", "\n", 
           "\n", 
           RowBox[{
            RowBox[{"PointsToRegress", "=", 
             RowBox[{"Transpose", "[", 
              RowBox[{"Drop", "[", 
               RowBox[{
                RowBox[{"Transpose", "[", "SinglePointsToSave", "]"}], ",", 
                RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", "\n", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"linfit", ",", "lmslinfit"}], "}"}], "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Fit", "[", 
                RowBox[{"PointsToRegress", ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}], ",", 
               RowBox[{"lmsfita", "[", 
                RowBox[{"PointsToRegress", ",", "x"}], "]"}]}], "}"}]}], ";", 
            "\n", "\n", 
            RowBox[{"PredictedLMSResponse", "=", 
             RowBox[{"lmslinfit", "/.", 
              RowBox[{"x", "\[Rule]", 
               RowBox[{
                RowBox[{"Transpose", "[", "PointsToRegress", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}]}]}]}], ";", "\n", 
            RowBox[{"LMSRatios", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Transpose", "[", "PointsToRegress", "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}], "/", 
              "PredictedLMSResponse"}]}], ";", "\n", "\n", 
            RowBox[{"GoodPoints", "=", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"Thread", "[", 
                RowBox[{"{", 
                 RowBox[{"LMSRatios", ",", "SinglePointsToSave"}], "}"}], 
                "]"}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ">", 
                   RowBox[{"1", "-", "ThisAcceptancePercentage"}]}], " ", "&&",
                   " ", 
                  RowBox[{
                   RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<", 
                   RowBox[{"1", "+", "ThisAcceptancePercentage"}]}]}], "  ", 
                 ")"}], "&"}]}], "]"}]}], ";"}]}], "\n", "]"}], ";", "\n", 
         "\n", 
         RowBox[{"ThisMinRSquare", "=", 
          RowBox[{"ThisMinRSquare", "-", "0.0125"}]}], ";", "\n", 
         RowBox[{"ThisAcceptancePercentage", "=", 
          RowBox[{"ThisAcceptancePercentage", "+", "0.005"}]}], ";"}]}], "\n",
        "\n", "]"}], ";", "\n", "\n", 
      RowBox[{"FinalRegressionPoints", "=", 
       RowBox[{
        RowBox[{"Transpose", "[", "GoodPoints", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\n", 
      RowBox[{"PointsToRegress", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "FinalRegressionPoints", "]"}], ",", 
          RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", "\n", 
      RowBox[{"FinalLinFit", "=", 
       RowBox[{
        RowBox[{"LinearModelFit", "[", 
         RowBox[{"PointsToRegress", ",", "x", ",", "x"}], "]"}], "[", 
        "\"\<BestFitParameters\>\"", "]"}]}], ";", "\n", 
      RowBox[{"FinalCalVal", "=", 
       RowBox[{"Mean", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Transpose", "[", "PointsToRegress", "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "/", 
         RowBox[{
          RowBox[{"Transpose", "[", "PointsToRegress", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"FinalDataPoints", "=", 
       RowBox[{"Transpose", "[", "FinalRegressionPoints", "]"}]}], ";", "\n", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "InitialCalVal", ",", " ", "InitialDataPoints", ",", " ", 
        "InitialLinFit", ",", "FinalCalVal", ",", " ", "FinalDataPoints", ",",
         " ", "FinalLinFit", ",", "lmslinfit", ",", 
        RowBox[{"ThisMinRSquare", "+", "0.0125"}], ",", 
        RowBox[{"ThisAcceptancePercentage", "-", "0.005"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 AutoIndent->False,
 CellChangeTimes->{{3.487345211618013*^9, 3.487345232705013*^9}, {
   3.4906278333611884`*^9, 3.4906278343691883`*^9}, {3.4906279670581884`*^9, 
   3.490628003279188*^9}, {3.4906331912301884`*^9, 3.4906332228131886`*^9}, {
   3.4906333094931884`*^9, 3.4906333328031883`*^9}, {3.4906334428847675`*^9, 
   3.490633461029945*^9}, {3.4906338662018943`*^9, 3.4906338701292496`*^9}, {
   3.4906339006445475`*^9, 3.4906339061378417`*^9}, {3.4906340867488213`*^9, 
   3.490634119668404*^9}, {3.4906994762750793`*^9, 3.4906995286344757`*^9}, 
   3.4910168725975447`*^9, 3.491017813322544*^9, {3.491017913584544*^9, 
   3.4910179834315443`*^9}, 3.4910180850335445`*^9, {3.4910181505005445`*^9, 
   3.4910181917935443`*^9}, {3.491018285768544*^9, 3.4910183545095444`*^9}, {
   3.491018468020544*^9, 3.4910185235035443`*^9}, {3.4910185837955446`*^9, 
   3.4910185910055447`*^9}, {3.4910186255335445`*^9, 
   3.4910186264655447`*^9}, {3.4910186674225445`*^9, 
   3.4910187622465444`*^9}, {3.491018806518544*^9, 3.4910189024565444`*^9}, {
   3.491048824233637*^9, 3.491048844722686*^9}, {3.491058571117228*^9, 
   3.491058574675584*^9}, {3.4910586152236385`*^9, 3.4910589051016235`*^9}, {
   3.491058986769789*^9, 3.4910590629204035`*^9}, {3.4910591220873194`*^9, 
   3.4910591339895096`*^9}, {3.491059364555564*^9, 3.491059445467654*^9}, {
   3.4910594907241793`*^9, 3.491059625533659*^9}, {3.491059959456048*^9, 
   3.491060087080809*^9}, {3.491060120173118*^9, 3.49106016139824*^9}, {
   3.491060194557556*^9, 3.4910602525823574`*^9}, {3.4910615563077173`*^9, 
   3.4910615887329597`*^9}, {3.4910617070447893`*^9, 3.491061717293814*^9}, {
   3.491061786637748*^9, 3.491061897537837*^9}, {3.4910619546135435`*^9, 
   3.491062066146696*^9}, {3.491062107077789*^9, 3.491062108609942*^9}, {
   3.4910621679948797`*^9, 3.49106230500558*^9}, {3.491062448265904*^9, 
   3.4910624774548225`*^9}, 3.4910632420402737`*^9, {3.491063277126782*^9, 
   3.49106329880995*^9}, {3.491063642487314*^9, 3.4910638785339165`*^9}, {
   3.4910639671527777`*^9, 3.491064034097471*^9}, {3.4910641231693773`*^9, 
   3.491064132214282*^9}, {3.491064271738233*^9, 3.4910642893659954`*^9}, {
   3.491064323945453*^9, 3.491064346301689*^9}, {3.491064396887747*^9, 
   3.491064474287486*^9}, {3.4910645310931664`*^9, 3.491064626755731*^9}, {
   3.4910646629383492`*^9, 3.491064713506406*^9}, {3.4910647563786926`*^9, 
   3.491064895436597*^9}, {3.4910649435404067`*^9, 3.4910649701810703`*^9}, {
   3.4910652166497145`*^9, 3.491065230381088*^9}, {3.4910658034113855`*^9, 
   3.491065812346278*^9}, {3.491068669395955*^9, 3.491068709557971*^9}, {
   3.4910687766096754`*^9, 3.4910687944954634`*^9}, {3.4910688649925127`*^9, 
   3.4910688766766806`*^9}, 3.4911292985706615`*^9, {3.4911294160734105`*^9, 
   3.4911296951683173`*^9}, {3.491129725171317*^9, 3.4911297516779675`*^9}, 
   3.4911298006608653`*^9, {3.4911299690877066`*^9, 3.4911300152583227`*^9}, {
   3.4911300798767843`*^9, 3.4911301049402905`*^9}, {3.491140363852079*^9, 
   3.491140398136507*^9}, {3.49114063699239*^9, 3.4911406877654667`*^9}, 
   3.4911445624362288`*^9, {3.4912165091845737`*^9, 3.4912165866205735`*^9}, {
   3.4912184814625735`*^9, 3.4912184972715735`*^9}, {3.491218527537574*^9, 
   3.491218563148574*^9}, {3.4912192185735736`*^9, 3.4912193470085735`*^9}, {
   3.4912205446855736`*^9, 3.4912205521375737`*^9}, {3.4912207554145737`*^9, 
   3.4912207614045734`*^9}, {3.501666462996584*^9, 3.501666480803584*^9}, {
   3.5021068683459826`*^9, 3.5021068702981777`*^9}, {3.502106943896537*^9, 
   3.5021069818223286`*^9}, {3.5021070179539413`*^9, 3.502107038308977*^9}, {
   3.5030734108406925`*^9, 3.5030734200556927`*^9}, {3.5036701312637672`*^9, 
   3.503670266521767*^9}, {3.503670316449767*^9, 3.503670388175767*^9}, {
   3.5036707652687674`*^9, 3.503670852402767*^9}, {3.503670901067767*^9, 
   3.5036710454607673`*^9}, {3.5037440438671117`*^9, 
   3.5037440986951118`*^9}, {3.5037441589851117`*^9, 
   3.5037441852681117`*^9}, {3.5037442343821115`*^9, 3.503744288487112*^9}, {
   3.5037443999361115`*^9, 3.5037444511111116`*^9}, {3.5037444839851117`*^9, 
   3.503744511046112*^9}, {3.503744628079112*^9, 3.5037446545771117`*^9}, {
   3.503762245427149*^9, 3.5037623379664016`*^9}, {3.503763000834682*^9, 
   3.5037630026898675`*^9}, {3.503763039709569*^9, 3.5037631148720846`*^9}, {
   3.503763150180615*^9, 3.503763182519849*^9}, {3.5037632214007363`*^9, 
   3.5037632218767843`*^9}, {3.503763780865677*^9, 3.5037637893185225`*^9}, {
   3.503763876685258*^9, 3.503763885576147*^9}, {3.5037640058041687`*^9, 
   3.5037640188884773`*^9}, {3.503764119278515*^9, 3.503764122019789*^9}, {
   3.503764996066185*^9, 3.5037649992725058`*^9}},
 LineIndent->0.]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Set the directory to where the input data files are located and read the data.\
\>", "Subsubtitle",
 CellChangeTimes->{{3.550937016801832*^9, 3.5509370399247847`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "SetDirectory", "[", 
   "\"\<C:\\\\Data\\\\Processed\\\\UWO_2012\\\\ALVICE\\\\CalExample\\\\\>\"", 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5509365372250814`*^9, 3.550936562693881*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RadioData", "=", 
   RowBox[{"<<", "\"\<RadioData.dat\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RH", "=", 
   RowBox[{"<<", "\"\<RH.dat\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TempK", "=", 
   RowBox[{"<<", "\"\<TempK.dat\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RadioHeights", "=", 
   RowBox[{"<<", "\"\<RadioHeights.dat\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CompositeData", "=", 
   RowBox[{"<<", "\"\<CompositeData.dat\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CompositeError", "=", 
   RowBox[{"<<", "\"\<SumErrorProfTest.dat\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LidarHeights", "=", 
    RowBox[{"<<", "\"\<LidarHeights.dat\>\""}]}], ";"}], " "}]}], "Input",
 CellChangeTimes->{{3.5509332368178806`*^9, 3.5509332571701202`*^9}, {
  3.5509333178355503`*^9, 3.5509333198791237`*^9}, {3.550935752635281*^9, 
  3.5509357550430813`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Execute the adaptive routine for the case of a single radiosonde - lidar \
comparison.\
\>", "Subsubtitle",
 CellChangeTimes->{{3.5509370632392383`*^9, 3.5509370874970827`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "InitialCalVal", ",", "InitialDataPoints", ",", "InitialLinFit", ",", 
     "FinalCalVal", ",", "FinalDataPoints", ",", "FinalLinFit", ",", 
     "lmslinfit", ",", "MinRSquareFinal", ",", "AcceptancePercentageFinal"}], 
    "}"}], "=", 
   RowBox[{"GetRadioCalFactorRegress", "[", 
    RowBox[{"RadioData", ",", "RH", ",", 
     RowBox[{"TempK", "-", "273.15"}], ",", "RadioHeights", ",", 
     RowBox[{"LidarData", "=", "CompositeData"}], ",", 
     RowBox[{"LidarDataErrs", "=", "CompositeError"}], ",", "LidarHeights", 
     ",", 
     RowBox[{"MinCalAlt", "=", "2.275"}], ",", 
     RowBox[{"MaxCalAlt", "=", "5.275"}], ",", 
     RowBox[{"MinRSquare", "=", "0.95"}], ",", 
     RowBox[{"RegressionIntervalKM", "=", "0.5"}], ",", 
     RowBox[{"AcceptancePercentage", "=", "0.03"}], ",", 
     RowBox[{"MinRegressPts", "=", "30"}], ",", 
     RowBox[{"MinRH", "=", "5"}], ",", 
     RowBox[{"MinTempC", "=", 
      RowBox[{"-", "50"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.5509367529961815`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package the data and plot.", "Subsubtitle",
 CellChangeTimes->{{3.550937051016115*^9, 3.550937059963259*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SondeProfilePoints", "=", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"InitialDataPoints", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"InitialDataPoints", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LidarProfilePoints", "=", 
    RowBox[{"Thread", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FinalCalVal", " ", 
        RowBox[{"InitialDataPoints", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", 
       RowBox[{"InitialDataPoints", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p1r", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"SondeProfilePoints", ",", "LidarProfilePoints"}], "}"}], ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"Axes", "\[Rule]", "False"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Mixing Ratio (g/kg)\>\"", ",", "\"\<Altitude (km)\>\""}],
         "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.9", " ", 
            RowBox[{"Min", "[", 
             RowBox[{"FinalCalVal", " ", 
              RowBox[{"FinalDataPoints", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ",", 
           RowBox[{"1.2", 
            RowBox[{"Max", "[", 
             RowBox[{"FinalCalVal", " ", 
              RowBox[{"FinalDataPoints", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"MinCalAlt", ",", "MaxCalAlt"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Black"}], "]"}], 
         ",", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red"}], "]"}]}], 
        "}"}]}], ",", 
      RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotLegend", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Sonde\>\"", ",", "\"\<Lidar\>\""}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.3", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "10"}], ",", 
      RowBox[{"LegendSpacing", "\[Rule]", "1"}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.3", ",", "0.2"}], "}"}]}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "False"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1ra", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"p1r", ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Framed", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<Before selection\>\"", ",", "12"}], "]"}], ",", 
          RowBox[{"Background", "\[Rule]", "LightYellow"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "0.45"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SondeFinalProfilePoints", "=", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FinalDataPoints", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"FinalDataPoints", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LidarFinalProfilePoints", "=", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FinalCalVal", " ", 
       RowBox[{"FinalDataPoints", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"FinalDataPoints", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.550925264770294*^9, 3.550925348417494*^9}, {
   3.5509254089922943`*^9, 3.550925515041094*^9}, 3.550932529693676*^9, {
   3.5509333301799917`*^9, 3.5509333449846053`*^9}, 3.550935879041381*^9, 
   3.5509367465221815`*^9, 3.550937045244152*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p2r", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"SondeFinalProfilePoints", ",", "LidarFinalProfilePoints"}], 
      "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "False"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Mixing Ratio (g/kg)\>\"", ",", "\"\<Altitude (km)\>\""}], 
       "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.9", " ", 
           RowBox[{"Min", "[", 
            RowBox[{"FinalCalVal", " ", 
             RowBox[{"FinalDataPoints", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"1.2", 
           RowBox[{"Max", "[", 
            RowBox[{"FinalCalVal", " ", 
             RowBox[{"FinalDataPoints", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"MinCalAlt", ",", "MaxCalAlt"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Black"}], "]"}], 
        ",", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red"}], "]"}]}], 
       "}"}]}], ",", 
     RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotLegend", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Sonde\>\"", ",", "\"\<Lidar\>\""}], "}"}]}], ",", 
     RowBox[{"LegendPosition", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.3", ",", "0.3"}], "}"}]}], ",", 
     RowBox[{"LegendTextSpace", "\[Rule]", "10"}], ",", 
     RowBox[{"LegendSpacing", "\[Rule]", "1"}], ",", 
     RowBox[{"LegendSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.3", ",", "0.2"}], "}"}]}], ",", 
     RowBox[{"LegendShadow", "\[Rule]", "False"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "}"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"p2ra", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"p2r", ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Framed", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<After selection\>\"", ",", "12"}], "]"}], ",", 
          RowBox[{"Background", "\[Rule]", "LightYellow"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "0.45"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"InitialRegressionPairs", "=", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"InitialDataPoints", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"InitialDataPoints", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FinalRegressionPairs", "=", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FinalDataPoints", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"FinalDataPoints", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p4r", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"InitialLinFit", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"InitialLinFit", "[", 
          RowBox[{"[", "2", "]"}], "]"}], " ", "x"}]}], ",", 
       RowBox[{
        RowBox[{"FinalLinFit", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"FinalLinFit", "[", 
          RowBox[{"[", "2", "]"}], "]"}], " ", "x"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", 
       RowBox[{"1.1", 
        RowBox[{"Max", "[", 
         RowBox[{"InitialDataPoints", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"1.1", " ", 
           RowBox[{"Max", "[", 
            RowBox[{"InitialDataPoints", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"1.1", " ", 
           RowBox[{"Max", "[", 
            RowBox[{"InitialDataPoints", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Lidar (uncal)\>\"", ",", "\"\<Sonde (g/kg)\>\""}], 
       "}"}]}], ",", 
     RowBox[{"PlotLegend", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Initial Regress\>\"", ",", "\"\<Final Regress\>\""}], 
       "}"}]}], ",", 
     RowBox[{"LegendPosition", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.4", ",", 
        RowBox[{"-", "0.2"}]}], "}"}]}], ",", 
     RowBox[{"LegendTextSpace", "\[Rule]", "10"}], ",", 
     RowBox[{"LegendSpacing", "\[Rule]", "0.2"}], ",", 
     RowBox[{"LegendSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.4", ",", "0.15"}], "}"}]}], ",", 
     RowBox[{"LegendShadow", "\[Rule]", "False"}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "}"}]}], 
     ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "/@", "InitialRegressionPairs"}], ",", "Red", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "/@", "FinalRegressionPairs"}], ",", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Framed", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"\"\<Calini = \>\"", "<>", 
                RowBox[{"ToString", "[", "InitialCalVal", "]"}], "<>", 
                "\"\<\\nCalfin= \>\"", "<>", 
                RowBox[{"ToString", "[", "FinalCalVal", "]"}], "<>", 
                "\"\<\\nMinRsq = \>\"", "<>", 
                RowBox[{"ToString", "[", "MinRSquareFinal", "]"}], "<>", 
                "\"\<\\nAcc%= \>\"", "<>", 
                RowBox[{"ToString", "[", "AcceptancePercentageFinal", "]"}]}],
                ",", "12"}], "]"}], ",", 
             RowBox[{"Background", "\[Rule]", "LightYellow"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"0.2", " ", 
              RowBox[{"Max", "[", 
               RowBox[{"InitialDataPoints", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
             RowBox[{"0.9", " ", 
              RowBox[{"Max", "[", 
               RowBox[{"InitialDataPoints", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "}"}]}], "]"}]}], 
        "}"}]}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export the graphic to see the results.", "Subsubtitle",
 CellChangeTimes->{{3.550937097392821*^9, 3.550937122561361*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<RadioCalAnalysisTest.gif\>\"", ",", 
    RowBox[{"GraphicsGrid", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p1ra", ",", "p2ra"}], "}"}], ",", 
        RowBox[{"{", "p4r", "}"}]}], "}"}], ",", 
      RowBox[{"Spacings", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "50"}], ",", "10"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}], ",", 
    RowBox[{"ImageResolution", "\[Rule]", "100"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5509332896567063`*^9, 3.5509333026879425`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1904, 945},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 710, 11, 389, "Title"],
Cell[1292, 35, 319, 4, 73, "Subsubtitle"],
Cell[1614, 41, 95, 2, 43, "Input"],
Cell[CellGroupData[{
Cell[1734, 47, 327, 6, 105, "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2064, 55, 989, 27, 152, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[3056, 84, 935, 26, 152, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[3994, 112, 1851, 49, 233, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[5848, 163, 921, 26, 70, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[6772, 191, 210, 3, 42, "Subsubtitle",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[6985, 196, 5921, 150, 178, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[12909, 348, 976, 18, 327, "Subsubtitle",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[13888, 368, 28183, 589, 3446, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[42108, 962, 177, 3, 42, "Subsubtitle"],
Cell[42288, 967, 232, 6, 43, "Input"],
Cell[42523, 975, 1023, 27, 206, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43583, 1007, 187, 4, 42, "Subsubtitle"],
Cell[43773, 1013, 1082, 24, 98, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44892, 1042, 115, 1, 42, "Subsubtitle"],
Cell[45010, 1045, 4651, 123, 341, "Input"],
Cell[49664, 1170, 2338, 61, 179, "Input"],
Cell[52005, 1233, 1194, 35, 98, "Input"],
Cell[53202, 1270, 3983, 100, 233, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57222, 1375, 127, 1, 42, "Subsubtitle"],
Cell[57352, 1378, 653, 17, 43, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
